pub(crate) fn parse_key_block_header(block: &[u8]) -> Result<KeyBlockHeader>Expand description
Parses the header of a key block from the full decompressed block data.
pub(crate) fn parse_key_block_header(block: &[u8]) -> Result<KeyBlockHeader>Parses the header of a key block from the full decompressed block data.